# PyDapi2
The *PyDapi2* library offers a Python implementation of the Dassym API version 2.

Dassym API version 2 aka **DAPI2** is the application programming interface (API) used to
control Dassym electronic boards.

This library was created to meet internal needs in Dassym. 